import { app } from '@/app.ts';
import { ConfigModel } from './models/model.ts';
import { oss } from '@/app.ts';
import { ConfigOssService } from '@kevisual/oss/services';
import { Op } from 'sequelize';

app
  .route({
    path: 'config',
    key: 'detect',
    middleware: ['auth'],
  })
  .define(async (ctx) => {
    const tokenUser = ctx.state.tokenUser;
    const owner = tokenUser.username;
    const configOss = ConfigOssService.fromBase({
      oss,
      opts: {
        owner,
      },
    });
    const { list, keys, keyEtagMap } = await configOss.getList();
    const configList = await ConfigModel.findAll({
      where: {
        key: {
          [Op.in]: keys,
        },
        uid: tokenUser.id,
      },
    });
    const needUpdateList = list.filter((item) => {
      const key = item.key;
      const hash = keyEtagMap.get(key);
      const config = configList.find((item) => item.key === key);
      if (!config) {
        return true;
      }
      return config?.hash !== hash;
    });
    const keyDataMap = await configOss.getObjectList(needUpdateList.map((item) => item.key));
    const updateList = [];
    for (const [key, json] of keyDataMap.entries()) {
      const keyETag = keyEtagMap.get(key);
      const configData = keyDataMap.get(key);
      if (keyETag && configData) {
        const [config, created] = await ConfigModel.findOrCreate({
          where: {
            key,
            uid: tokenUser.id,
          },
          defaults: {
            key,
            title: key,
            description: `从${key}:${keyETag} 同步而来`,
            uid: tokenUser.id,
            hash: keyETag,
            data: configData,
          },
        });
        if (!created) {
          await config.update(
            {
              hash: keyETag,
              data: json,
            },
            {
              fields: ['hash', 'data'],
            },
          );
        }
        updateList.push(config);
      }
    }
    ctx.body = {
      updateList,
    };
  })
  .addTo(app);
